@@ -1,16 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""
-* Date: 29.07.13
-* Time: 0:11
-* Original filename: 
-"""
-
 from __future__ import print_function, absolute_import
 from .parser import Parser
 from . import validators
 
 __author__ = 'mosquito'
 __all__ = [Parser, validators]
-__version__ = "0.4.1"
\ No newline at end of file
+__version__ = "0.5.12"
